@@ -4,13 +4,13 @@ use strict;
 use warnings;
 
 use Class::Utils qw(set_params);
-use Encode qw(encode);
+use Encode;
 use Error::Pure qw(err);
 use PYX qw(char comment);
 use PYX::Parser;
 use PYX::Utils;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -82,7 +82,7 @@ sub _data {
 
 	$data = PYX::Utils::decode($tmp);
 	my $out = $pyx_parser_obj->{'output_handler'};
-	my $encoded_output = encode(
+	my $encoded_output = Encode::encode(
 		$pyx_parser_obj->{'non_parser_options'}->{'output_encoding'},
 		char($data),
 	);
@@ -100,7 +100,7 @@ sub _comment {
 	$tmp =~ s/[\s\n]*$//s;
 	$comment = PYX::Utils::decode($tmp);
 	my $out = $pyx_parser_obj->{'output_handler'};
-	my $encoded_output = encode(
+	my $encoded_output = Encode::encode(
 		$pyx_parser_obj->{'non_parser_options'}->{'output_encoding'},
 		comment($comment),
 	);
@@ -272,6 +272,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
